@@ -1,8 +1,8 @@
 use async_trait::async_trait;
 use colored::*;
 use serde_json::json;
+use serde_yaml::Value;
 use std::process::Command;
-use yaml_rust::Yaml;
 
 use crate::actions::Runnable;
 use crate::actions::{extract, extract_optional};
@@ -18,13 +18,14 @@ pub struct Exec {
 }
 
 impl Exec {
-  pub fn is_that_you(item: &Yaml) -> bool {
-    item["exec"].as_hash().is_some()
+  pub fn is_that_you(item: &Value) -> bool {
+    item.get("exec").and_then(|v| v.as_mapping()).is_some()
   }
 
-  pub fn new(item: &Yaml, _with_item: Option<Yaml>) -> Exec {
+  pub fn new(item: &Value, _with_item: Option<Value>) -> Exec {
     let name = extract(item, "name");
-    let command = extract(&item["exec"], "command");
+    let exec_val = item.get("exec").expect("exec field is required");
+    let command = extract(exec_val, "command");
     let assign = extract_optional(item, "assign");
 
     Exec {
@@ -44,7 +45,7 @@ impl Runnable for Exec {
 
     let final_command = interpolator::Interpolator::new(context).resolve(&self.command, !config.relaxed_interpolations);
 
-    let args = vec!["bash", "-c", "--", final_command.as_str()];
+    let args = ["bash", "-c", "--", final_command.as_str()];
 
     let execution = Command::new(args[0]).args(&args[1..]).output().expect("Couldn't run it");
 
